/*
  Jar Jar Links - A utility to repackage and embed Java libraries
  Copyright (C) 2004  Tonic Systems, Inc.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  if not, write to
  the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA 02111-1307 USA
*/

package com.tonicsystems.jarjar;

import com.tonicsystems.jarjar.util.*;
import java.io.*;
import java.util.*;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import org.objectweb.asm.*;
import org.objectweb.asm.Type;
import org.objectweb.asm.commons.EmptyVisitor;
import org.objectweb.asm.signature.*;

class DepFindVisitor extends DependencyVisitor
{
    private Map classes;
    private String source;
    private DepHandler handler;
    private PathClass curPathClass;

    public DepFindVisitor(Map classes, Object source, DepHandler handler) throws IOException {
        super(new EmptyVisitor());
        this.classes = classes;
        this.source = getSourceName(source);
        this.handler = handler;
    }

    public void visit(int version, int access, String name, String signature, String superName, String[] interfaces) {
        curPathClass = new PathClass(source, name);
        super.visit(version, access, name, signature, superName, interfaces);
    }

    protected String fixDesc(String desc) {
        int index = desc.indexOf('L');
        if (index >= 0)
            fixName(desc.substring(index + 1, desc.length() - 1));
        return desc;
    }        
    
    protected String fixMethodDesc(String desc) {
        fixDesc(Type.getReturnType(desc).getDescriptor());
        Type[] args = Type.getArgumentTypes(desc);
        for (int i = 0; i < args.length; i++)
            fixDesc(args[i].getDescriptor());
        return desc;
    }
    
    protected String fixName(String name) {
        try {
            if (classes.containsKey(name)) {
                String otherSource = getSourceName(classes.get(name));
                if (!source.equals(otherSource)) {
                    // TODO: some escape mechanism?
                    handler.handle(curPathClass, new PathClass(otherSource, name));
                }
            }
            return name;
        } catch (IOException e) {
            throw new RuntimeIOException(e);
        }
    }

    private String getSourceName(Object source) throws IOException {
        if (source instanceof ZipFile) {
            return ((ZipFile)source).getName();
        } else {
            return ((File)source).getCanonicalPath();
        }
    }
    
    protected String fixString(String className, String value) {
        // TODO?
        return value;
    }

    protected Attribute fixAttribute(Attribute attrs) {
        // TODO?
        return attrs;
    }
}
